@@ -4,31 +4,19 @@
  */
 
 #pragma once
-#include <aws/firehose/Firehose_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/firehose/Firehose_EXPORTS.h>
 
-namespace Aws
-{
-namespace Firehose
-{
-namespace Model
-{
-  enum class ElasticsearchIndexRotationPeriod
-  {
-    NOT_SET,
-    NoRotation,
-    OneHour,
-    OneDay,
-    OneWeek,
-    OneMonth
-  };
+namespace Aws {
+namespace Firehose {
+namespace Model {
+enum class ElasticsearchIndexRotationPeriod { NOT_SET, NoRotation, OneHour, OneDay, OneWeek, OneMonth };
 
-namespace ElasticsearchIndexRotationPeriodMapper
-{
+namespace ElasticsearchIndexRotationPeriodMapper {
 AWS_FIREHOSE_API ElasticsearchIndexRotationPeriod GetElasticsearchIndexRotationPeriodForName(const Aws::String& name);
 
 AWS_FIREHOSE_API Aws::String GetNameForElasticsearchIndexRotationPeriod(ElasticsearchIndexRotationPeriod value);
-} // namespace ElasticsearchIndexRotationPeriodMapper
-} // namespace Model
-} // namespace Firehose
-} // namespace Aws
+}  // namespace ElasticsearchIndexRotationPeriodMapper
+}  // namespace Model
+}  // namespace Firehose
+}  // namespace Aws
