@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/firehose/Firehose_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/firehose/Firehose_EXPORTS.h>
 
-namespace Aws
-{
-namespace Firehose
-{
-namespace Model
-{
-  enum class SnapshotStatus
-  {
-    NOT_SET,
-    IN_PROGRESS,
-    COMPLETE,
-    SUSPENDED
-  };
+namespace Aws {
+namespace Firehose {
+namespace Model {
+enum class SnapshotStatus { NOT_SET, IN_PROGRESS, COMPLETE, SUSPENDED };
 
-namespace SnapshotStatusMapper
-{
+namespace SnapshotStatusMapper {
 AWS_FIREHOSE_API SnapshotStatus GetSnapshotStatusForName(const Aws::String& name);
 
 AWS_FIREHOSE_API Aws::String GetNameForSnapshotStatus(SnapshotStatus value);
-} // namespace SnapshotStatusMapper
-} // namespace Model
-} // namespace Firehose
-} // namespace Aws
+}  // namespace SnapshotStatusMapper
+}  // namespace Model
+}  // namespace Firehose
+}  // namespace Aws
